Changelog
=========

### 1.2.1 (23/03/2020)

- Django 3 import fix. PR: https://github.com/ixc/wagtail-instance-selector/pull/2.


### 1.1.0 (23/09/2019)

- Added hooks to enable selection on non-standard list views.


### 1.0.1 (06/06/2019)

- PyPI fix.


### 1.0.0 (06/06/2019)

- Initial release.
